@@ -83,7 +83,7 @@ def main(arg_vars: list = None):
 
 def test_repository_folders_command(command_args, config):
     parser = argparse.ArgumentParser(f"{NAME} [...] {Commands.TEST_REPOSITORY_FOLDERS}")
-    parser.add_argument('--folder', help='Choose a folder, else "root"')
+    parser.add_argument('--folder', default='/', help='Choose a folder, else "root"')
     args = parser.parse_args(command_args)
 
     xray = XrayWrapper(config)
@@ -127,9 +127,12 @@ def upload_features_command(command_args, config):
     for feature_path in feature_paths:
         features += cucumber.get_features(feature_path)
 
+    if not features:
+        print('No Feature found')
+
     xray = XrayWrapper(config)
     for feature in features:
-        print(f'Processing feature: "{feature.name} (path={feature.path})"')
+        print(f'Processing feature: {feature.name} (path="{feature.path}")')
 
         # check if there are test with the same name
         if issues := xray.get_issues_by_names([x.name for x in feature.scenarios]):
@@ -186,11 +189,12 @@ def upload_features_command(command_args, config):
         print('Repairing feature tags')
         feature.repair_tags()
         print('Validating result')
-        xray.import_feature(feature.path)
-        print(f'Feature updated successfully: "{feature.name}"')
+        xray.import_feature(feature)
+        print(f'Feature updated successfully: {feature.name}')
 
 
 if __name__ == '__main__':
+    pass
     # main(['-h'])
     # main(['-h', Commands.TEST_REPOSITORY_FOLDERS])
     # main(['-h', '--config', 'bddfile.yml', Commands.TEST_REPOSITORY_FOLDERS])
@@ -210,4 +214,4 @@ if __name__ == '__main__':
     #
     # main([Commands.UPLOAD, '-h'])
     # main([Commands.UPLOAD_FEATURES, r'features\Verisure OWA\Wrapper Android'])
-    main([Commands.UPLOAD_FEATURES, r'C:\workspaces\bddsync\features\Verisure OWA\Web\panelstatus.feature'])
+    # main([Commands.UPLOAD_FEATURES, r'C:\workspaces\bddsync\features\Verisure OWA\Web\actionplans.feature'])
